-- -----------------------------------------------------
-- Table `#__bookitcategory`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `#__bookitcategory` (
  `idcategory` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `name` TEXT NULL ,
  `nguests` INT UNSIGNED NULL ,
  `nchilds` INT UNSIGNED NULL ,
  `cost` FLOAT UNSIGNED NULL ,
  `facilities` TEXT NULL ,
  `description` TEXT NULL ,
  `url` VARCHAR(45) NULL ,
  `adult_cost` FLOAT UNSIGNED NULL ,
  `child_cost` FLOAT UNSIGNED NULL ,
  `nguests_min` INT UNSIGNED NULL ,
  `nchilds_min` INT UNSIGNED NULL ,
  `min_stay` INT UNSIGNED NULL ,
  `max_stay` INT UNSIGNED NULL ,
  `price_mode` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0=per room, 1=per guest',
  `max_in_total` INT UNSIGNED NULL COMMENT 'max guests in total either adults or children',
  `min_in_total` INT UNSIGNED NULL COMMENT 'min guests in total either adults or children',
  `start_day` CHAR(13) NULL,
  `end_day` CHAR(13) NULL,
  PRIMARY KEY (`idcategory`) )
PACK_KEYS = 0
ROW_FORMAT = DEFAULT
ENGINE=MyISAM 
AUTO_INCREMENT=0
DEFAULT CHARSET=utf8;

-- -----------------------------------------------------
-- Table `#__bookitroom`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `#__bookitroom` (
  `idroom` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idcategory` INT UNSIGNED NULL DEFAULT NULL ,
  `name` TEXT NULL DEFAULT NULL ,
  `description` TEXT NULL ,
  `url` VARCHAR(45) NULL ,
  PRIMARY KEY (`idroom`) ,
  INDEX `idcategory` (`idcategory` ASC) ,
  CONSTRAINT `idcategory`
    FOREIGN KEY (`idcategory` )
    REFERENCES `mydb`.`#__bookitcategory` (`idcategory` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
AUTO_INCREMENT = 0
DEFAULT CHARACTER SET = utf8
PACK_KEYS = 0
ROW_FORMAT = DEFAULT;

-- -----------------------------------------------------
-- Table `#__bookitextra`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `#__bookitextra` (
  `idextra` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `name` TEXT NULL DEFAULT NULL ,
  `extra_type` INT UNSIGNED NULL DEFAULT NULL COMMENT '1=required; 0=optional' ,
  `value_fix` FLOAT UNSIGNED NULL DEFAULT NULL ,
  `value_percent` FLOAT UNSIGNED NULL DEFAULT NULL ,
  `value_type` INT UNSIGNED NULL DEFAULT NULL COMMENT '1=booking; 2=night; 
  3=guest; 4=adult; 5=child; 6=quantity; 7=guest/night; 8=adult/night; 
  9=child/night; 10=quantity/night; ' ,
  `description` TEXT NULL ,
  `idcategories` TEXT NULL ,
  `published` tinyint(1) NOT NULL DEFAULT '1',
  `ordering` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`idextra`) )
ENGINE = MyISAM
AUTO_INCREMENT = 0
DEFAULT CHARACTER SET = utf8
PACK_KEYS = 0
ROW_FORMAT = DEFAULT;


-- -----------------------------------------------------
-- Table `#__bookitguests`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `#__bookitguests` (
  `idguests` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idcountry` INT UNSIGNED NULL DEFAULT NULL ,
  `name` TEXT NULL DEFAULT NULL ,
  `surname` TEXT NULL DEFAULT NULL ,
  `email` TEXT NULL DEFAULT NULL ,
  `address2` TEXT NULL DEFAULT NULL ,
  `address1` TEXT NULL DEFAULT NULL ,
  `phone` TEXT NULL DEFAULT NULL ,
  `address3` TEXT NULL DEFAULT NULL ,
  `postcode` TEXT NULL DEFAULT NULL ,
  `jid` INT UNSIGNED NULL DEFAULT NULL ,
  PRIMARY KEY (`idguests`) ,
  INDEX `guests_FKIndex1` (`idcountry` ASC) ,
  INDEX `idcountry` (`idcountry` ASC) ,
  CONSTRAINT `idcountry`
    FOREIGN KEY (`idcountry` )
    REFERENCES `mydb`.`#__bookitcountry` (`idcountry` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
AUTO_INCREMENT = 0
DEFAULT CHARACTER SET = utf8
PACK_KEYS = 0
ROW_FORMAT = DEFAULT;

-- -----------------------------------------------------
-- Table `#__bookitbooking`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `#__bookitbooking` (
  `idbook` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idcoupon` INT UNSIGNED NOT NULL ,
  `idroom` INT UNSIGNED NULL ,
  `idcategory` INT UNSIGNED NULL ,
  `idguests` INT UNSIGNED NULL ,
  `nguests` INT UNSIGNED NULL ,
  `value_paid` FLOAT UNSIGNED NULL DEFAULT NULL ,
  `value_pending` FLOAT UNSIGNED NULL DEFAULT NULL ,
  `value_full` FLOAT UNSIGNED NULL DEFAULT NULL ,
  `value_deposit` FLOAT UNSIGNED NULL DEFAULT NULL ,
  `valid_from` DATE NULL DEFAULT NULL ,
  `valid_to` DATE NULL DEFAULT NULL ,
  `today` DATE NULL DEFAULT NULL ,
  `extra_ids` TEXT NULL DEFAULT NULL ,
  `nchilds` INT UNSIGNED NULL ,
  `preferences` TEXT NULL DEFAULT NULL ,
  `status` INT UNSIGNED NULL COMMENT '0=available; 1=booked; 2=pending; 3=closed; 4=expired; 5=cancelled; 6=processing ',
  `lang` TEXT NULL DEFAULT NULL ,
  `rule_ids` TEXT NULL DEFAULT NULL ,
  `timestamp` TIMESTAMP NULL DEFAULT NOW(),
  `coids` TEXT NULL DEFAULT NULL ,
  `transaction_id` TEXT NULL DEFAULT NULL ,
  `staffnotes` TEXT NULL DEFAULT NULL,
  `payment_requested` TINYINT(1) NOT NULL DEFAULT '0',
  `payment_method` TEXT NULL DEFAULT NULL,
  `initial_price` FLOAT UNSIGNED NULL DEFAULT NULL ,
  PRIMARY KEY (`idbook`) ,
  INDEX `booking_FKIndex1` (`idcoupon` ASC) ,
  INDEX `booking_FKIndex2` (`idguests` ASC) ,
  CONSTRAINT `fk_{A80D650A-D332-468E-A00C-6CDCA3860F92}`
    FOREIGN KEY (`idcoupon` )
    REFERENCES `coupon` (`idcoupon` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_{8C046A06-5764-4F81-B1BD-89A9E3B46EA5}`
    FOREIGN KEY (`idguests` )
    REFERENCES `guests` (`idguests` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
PACK_KEYS = 0
ROW_FORMAT = DEFAULT
ENGINE=MyISAM 
AUTO_INCREMENT=0
DEFAULT CHARSET=utf8;

-- -----------------------------------------------------
-- Table `#__bookitrules`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `#__bookitrules` (
  `idrule` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `idcategory` TEXT NULL ,
  `name` TEXT NULL DEFAULT NULL ,
  `value` FLOAT UNSIGNED NULL DEFAULT NULL ,
  `value_child` FLOAT UNSIGNED NULL DEFAULT NULL ,
  `value_mode` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0=fixed, 1=percentage',
  `mode` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0=special_rate, 1=offer, 
  	2=extra_charge' ,
  `published` tinyint(1) NOT NULL DEFAULT '1',
  `valid_from` DATE NULL DEFAULT NULL ,
  `valid_to` DATE NULL DEFAULT NULL ,
  `type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0=rate_per_period, 
  	1=rate_per_day, 2=after_x_days, 3=over_x_adults , 4=over_x_children 5=over_x_guest
  	6=before_x_days, 7=under_x_adults , 8=under_x_children 9=under_x_guest',
  `xvar` INT UNSIGNED,
  `selected_days` TEXT NULL DEFAULT NULL ,
  `apply_on` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0=total amount, 1=daily rate',
  `price_mode` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0=per room, 1=per guest',
  `coupon` tinyint(1) NOT NULL DEFAULT '0',
  `quantity` INT UNSIGNED NULL DEFAULT '1',
  `times_used` INT NULL DEFAULT '0',
  `code` TEXT NULL DEFAULT NULL,
  PRIMARY KEY (`idrule`) )
ENGINE = MyISAM
AUTO_INCREMENT = 0
DEFAULT CHARACTER SET = utf8
PACK_KEYS = 0
ROW_FORMAT = DEFAULT;

-- -----------------------------------------------------
-- Table `#__bookitcountry`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `#__bookitcountry` (
  `idcountry` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
  `abbv` TEXT NULL,
  `name` TEXT NULL ,
  PRIMARY KEY (`idcountry`) )
PACK_KEYS = 0
ROW_FORMAT = DEFAULT
ENGINE=MyISAM 
AUTO_INCREMENT=0
DEFAULT CHARSET=utf8;

-- -----------------------------------------------------
-- Table `#__bookitutils`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `#__bookitutils` (
  `id` INT UNSIGNED NOT NULL,
  `terms_conditions` TEXT NULL ,
  `cancellation_policy` TEXT NULL ,
  `form_msg` TEXT NULL ,
  `pending_enabled` tinyint(1) NOT NULL DEFAULT '0',
  `pending_time` INT NOT NULL DEFAULT '0',
  `pending_measure` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0=Month 1=Week 2=day, 3=hour, 4=minute',
  `custemail_subject` TEXT NULL,
  `adminemail_subject` TEXT NULL, 
  `custverified_subject` TEXT NULL,
  `custprebooking_subject` TEXT NULL,
  `adminprebooking_subject` TEXT NULL,
  `show_address`  tinyint(1) NOT NULL DEFAULT '1',
  `show_phone`  tinyint(1) NOT NULL DEFAULT '1',
  `address_req`  tinyint(1) NOT NULL DEFAULT '1',
  `phone_req`  tinyint(1) NOT NULL DEFAULT '1',
  `show_captcha` tinyint(1) NOT NULL DEFAULT '1',
  `privatekey` TEXT NULL, 
  `publickey` TEXT NULL, 
  `captcha_theme` TEXT NULL, 
  `adminemail` TEXT NULL, 
  `custemail` TEXT NULL,
  `custverified` TEXT NULL,
  `custprebooking` TEXT NULL,
  `adminprebooking` TEXT NULL,
  `session_cnt` BIGINT UNSIGNED NOT NULL DEFAULT '1', 
  `show_address3`  tinyint(1) NOT NULL DEFAULT '1',
  `surname_req`  tinyint(1) NOT NULL DEFAULT '1',
  `show_postcode`  tinyint(1) NOT NULL DEFAULT '1',
  `postcode_req`  tinyint(1) NOT NULL DEFAULT '1',
 PRIMARY KEY (`id`) )
PACK_KEYS = 0
ROW_FORMAT = DEFAULT
ENGINE=MyISAM 
AUTO_INCREMENT=0
DEFAULT CHARSET=utf8;

-- -----------------------------------------------------
-- Table `#__bookitparams`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `#__bookitparams` (
  `id` INT UNSIGNED NOT NULL DEFAULT '1',
  `multiroom` tinyint(1) NOT NULL DEFAULT '0' ,
  `dateformat` INT NOT NULL DEFAULT '1' COMMENT '1=Y-m-d, 2=m-d-Y, 3=d-m-Y',
  `currency` VARCHAR(10) NOT NULL DEFAULT 'EUR',
  `max_booking_period` INT NOT NULL DEFAULT '365',
  `daysForCancellation` INT NOT NULL DEFAULT '30',
  `available_color` VARCHAR(10) NOT NULL DEFAULT 'F2FCFF',
  `booked_color` VARCHAR(10) NOT NULL DEFAULT 'FF6666',
  `pending_color` VARCHAR(10) NOT NULL DEFAULT 'FFCC66',
  `other_color` VARCHAR(10) NOT NULL DEFAULT 'CCCCFF',
  `show_available` tinyint(1) NOT NULL DEFAULT '1' ,
  `show_booked` tinyint(1) NOT NULL DEFAULT '1' ,
  `show_pending` tinyint(1) NOT NULL DEFAULT '1' ,
  `show_extra` tinyint(1) NOT NULL DEFAULT '1' ,
  `show_coupons` tinyint(1) NOT NULL DEFAULT '1' ,
  `deposit_percent` FLOAT UNSIGNED NOT NULL DEFAULT '0.00',
  `deposit_fixed` FLOAT UNSIGNED NOT NULL DEFAULT '0.00',
  `admin_email` TEXT NULL,
  `admin_email2` TEXT NULL, 
  `ok_url` TEXT NULL, 
  `failure_url` TEXT NULL, 
  `auto_confirm` tinyint(1) NOT NULL DEFAULT '1' ,
  `show_calendar` tinyint(1) NOT NULL DEFAULT '1' ,
  `show_year_calendar` tinyint(1) NOT NULL DEFAULT '0' ,
  `show_daily_rates` tinyint(1) NOT NULL DEFAULT '0' ,
  `start_monday` tinyint(1) NOT NULL DEFAULT '0' ,
  `last_date` DATE ,
  `normalize` tinyint(1) NOT NULL DEFAULT '0' ,
  `late_booking` INT UNSIGNED NULL DEFAULT '0',
  `show_bar` tinyint(1) NOT NULL DEFAULT '1' ,
  `new_template` tinyint(1) NOT NULL DEFAULT '1' ,
  `admin_confirm` tinyint(1) NOT NULL DEFAULT '0' ,
  `prebooking_url` TEXT NULL,
  PRIMARY KEY (`id`) )
PACK_KEYS = 0
ROW_FORMAT = DEFAULT
ENGINE=MyISAM 
AUTO_INCREMENT=0
DEFAULT CHARSET=utf8;