<?php
/**
 * BlooKing - The King in Joomla Booking
 * @version 1.0
 * @author BlooKing.org. Based on BooKiTGold code by Costas Kakousis
 * @copyright (C) 2012-2013 by BlooKing.org (http://www.blooking.org)
 * @license GNU/GPL: http://www.gnu.org/copyleft/gpl.html
 *
 * If you fork this to create your own project, please make a reference to
 * BlooKing! someplace in your code and provide a link to
 * http://www.blooking.org
 *
 * This file is part of BlooKing! BlooKing is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * BlooKing is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details. You should have received a copy of the GNU General Public License
 * along with BlooKing.  If not, see <http://www.gnu.org/licenses/>.
 *   ______ __                __  __ __
 *	|   __ \  |.-----..-----.|  |/  |__|.-----..-----.
 *	|   __ <  ||  _  ||  _  ||     <|  ||     ||  _  |
 *	|______/__||_____||_____||__|\__|__||__|__||___  |
 *                                             |_____|
 **/
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

class BlookingModelRules extends JModel {
	var $_data=null;
	var $_total = null;
	var $_pagination = null;

	function __construct() {
		parent::__construct();
		$mainframe = JFactory::getApplication();

		$limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
		$limitstart = JRequest::getVar('limitstart', 0, '', 'int');

		$limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);
	}

	function _buildQuery() {
		$modeSpecialPrice = JText::_("COM_BOOKIT_SPECIAL_PRICE"); //0
		$modeOffer = JText::_("COM_BOOKIT_OFFER"); //1
		$modeExtraCharge = JText::_("COM_BOOKIT_EXTRA_CHARGE"); //2

		$typePerPeriod = JText::_("COM_BOOKIT_PER_X_PERIOD_RATE"); //0
		$typePerDay = JText::_("COM_BOOKIT_PER_DAY_RATE"); //1
		$typeAfterDays = JText::_("COM_BOOKIT_AFTER_X_DAYS_RATE"); //2
		$typeOverAdults = JText::_("COM_BOOKIT_OVER_X_ADULTS_RATE"); //3
		$typeOverChilds = JText::_("COM_BOOKIT_OVER_X_CHILDREN_RATE"); //4
		$typeOverGuests = JText::_("COM_BOOKIT_OVER_X_GUEST"); //5
		//v1.5.4.2 7=under_x_adults , 8=under_x_children 9=under_x_guest
		$typeUnderAdults= JText::_("COM_BOOKIT_UNDER_X_ADULTS_RATE");//7
		$typeUnderChilds= JText::_("COM_BOOKIT_UNDER_X_CHILDREN_RATE");
		$typeUnderGuests= JText::_("COM_BOOKIT_UNDER_X_GUEST");
		//v1.5.4.3 6=before_x_days
		$typeUnderDays= JText::_("COM_BOOKIT_UNDER_X_DAYS");//6

		$db =& $this->_db;
		$query = 'SELECT *, CASE '.$db->nameQuote('mode').
		' WHEN 0 THEN '.$db->quote($modeSpecialPrice).
		' WHEN 1 THEN '.$db->quote($modeOffer).
		' WHEN 2 THEN '.$db->quote($modeExtraCharge).
		' END AS '.$db->nameQuote('modeStr').', CASE '.$db->nameQuote('type').
		' WHEN 0 THEN '.$db->quote($typePerPeriod).
		' WHEN 1 THEN '.$db->quote($typePerDay).
		' WHEN 2 THEN '.$db->quote($typeAfterDays).
		' WHEN 3 THEN '.$db->quote($typeOverAdults).
		' WHEN 4 THEN '.$db->quote($typeOverChilds).
		' WHEN 5 THEN '.$db->quote($typeOverGuests).
		' WHEN 6 THEN '.$db->quote($typeUnderDays).//v1.5.4.3
		' WHEN 7 THEN '.$db->quote($typeUnderAdults).//v1.5.4.2
		' WHEN 8 THEN '.$db->quote($typeUnderChilds).//v1.5.4.2
		' WHEN 9 THEN '.$db->quote($typeUnderGuests).//v1.5.4.2
		' END AS '.$db->nameQuote('typeStr').' FROM '.$db->nameQuote('#__bookitrules');
		$query .= $this->_buildQueryWhere();
		$query .= $this->_buildContentOrderBy();
		return $query;
	}

	function _buildContentOrderBy() {
		$option = JRequest::getCmd('option');
		$mainframe = JFactory::getApplication();
		$db =& $this->_db;
		$orderby = '';

		$orders = array('idrule', 'name', 'valid_from', 'valid_to', 'modeStr', 'typeStr', 'published', 'coupon');
		$filter_order = $mainframe->getUserStateFromRequest($option.'filter_order','filter_order','name');
		$filter_order_Dir = $mainframe->getUserStateFromRequest($option.'filter_order_Dir','filter_order_Dir','ASC');

		if($filter_order_Dir != 'ASC' && $filter_order_Dir != 'DESC') {
			$filter_order_Dir != 'ASC';
		}

		if (!in_array($filter_order, $orders)) {
			$filter_order='name';
		}

		$orderby = ' ORDER BY '.$db->nameQuote($filter_order).' '.$filter_order_Dir;

		if ($filter_order != 'name') {
			$orderby .= ' , '.$db->nameQuote('name');
		}

		return $orderby;
	}

	function _buildQueryWhere() {
		$filter_search = JRequest::getVar('filter_search');
		$where = array();

		if ($filter_search = trim($filter_search)) {
			$filter_search = JString::strtolower ($filter_search);
			$filter_search = $this->_db->getEscaped($filter_search);
			$where = ' WHERE (LOWER('.$this->_db->nameQuote('#__bookitrules').'.'.
					$this->_db->nameQuote('name').') LIKE "%'.$filter_search.'%" '.
					'OR ("'.$filter_search.'" BETWEEN '.$this->_db->nameQuote('#__bookitrules').'.'.
					$this->_db->nameQuote('valid_from').' AND '.
					$this->_db->nameQuote('#__bookitrules').'.'.$this->_db->nameQuote('valid_to').'))';
		}

		return (count($where)) ? $where : ' ';
	}


	function getData() {
		if (empty($this->_data)) {
			$query = $this->_buildQuery();
			$this->_data = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));
		}

		//die($this->_db->getQuery());
		return $this->_data;
	}

	function getTotal() {
		if (empty($this->_total)) {
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);
		}
		return $this->_total;
	}
	 
	function getPagination() {
		if (empty($this->_pagination)) {
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination($this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}
		return $this->_pagination;
	}

	function _buildCopyQuery($id) {
		$db =& $this->_db;
		$query = ' SELECT * FROM '.$db->nameQuote('#__bookitrules').' WHERE '.
				$db->nameQuote('idrule').'='.$db->Quote($id);
		$db->setQuery($query);
		$row = $db->loadObject();

		$data =new stdClass();
		$data->idrule = null;
		$data->idcategory = $row->idcategory;
		$data->name = "Copy of ".$row->name;
		$data->value = $row->value;
		$data->value_child = $row->value_child;
		$data->value_mode = $row->value_mode;
		$data->mode = $row->mode;
		$data->published = $row->published;
		$data->valid_from = $row->valid_from;
		$data->valid_to = $row->valid_to;
		$data->type = $row->type;
		$data->xvar = $row->xvar;
		$data->apply_on = $row->apply_on;
		$data->price_mode = $row->price_mode;
		$data->coupon=$row->coupon;
		$data->quantity=$row->quantity;
		$data->times_used=$row->times_used;
		$data->code=$row->code;

		$db->insertObject( '#__bookitrules', $data, 'idrule' );
		return true;
	}

	function delete() {
		$cids = JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$row =& $this->getTable('rulesedit');

		foreach($cids as $cid) {
			if (!$row->delete( $cid )) {
				$this->setError( $row->getErrorMsg() );
				return false;
			}
		}

		return true;
	}

	function copy () {
		$cids = JRequest::getVar( 'cid', array(0), 'post', 'array' );

		foreach($cids as $cid) {
			if (!$this->_buildCopyQuery($cid)) {
				return false;
			}
		}

		return true;
	}

	function publish() {
		$cid = JRequest::getVar( 'cid', array(), '', 'array' );

		if( JRequest::getVar('task') == 'publish') {
			$publish = 1;
		} else {
			$publish = 0;
		}

		$row =& $this->getTable('rulesedit');
		$result = $row->publish($cid, $publish);

		return $result;
	}

	function getCategoryName($catID) {
		$db =& JFactory::getDBO();
		$catNames = array();
		if ($catID=="" || $catID=="-1")
			return JText::_("COM_BOOKIT_NONE");
		else
		{
			$ids=explode(",",$catID);
			foreach ($ids as $id)
			{
				$query = "SELECT name FROM ".
						$db->nameQuote('#__bookitcategory')." WHERE ".
						$db->nameQuote("idcategory")."=".$id;
				$db->setQuery( $query );
				array_push ($catNames, $db->loadResult());
			}
		}

		return implode(",",$catNames);
	}
}